;EFW crib sheet for the mini-GEM meeting at Fall AGU 2012



	date = '2012-10-18'
	timespan,date,1
	sc = 'a'


	
	;...stuff to make plots pretty	
	rbsp_efw_init
	!p.charsize = 1.2
	tplot_options,'xmargin',[20.,15.]
	tplot_options,'ymargin',[3,6]
	tplot_options,'xticklen',0.08
	tplot_options,'yticklen',0.02
	tplot_options,'xthick',2
	tplot_options,'ythick',2




	
	;Get B1 and B2 availability
	rbsp_load_efw_burst_times,probe=sc
	options,['rbsp'+sc+'_efw_vb2_available',$
			 'rbsp'+sc+'_efw_vb1_available'],'colors',0	
		
	
	rbsp_load_efw_waveform,probe=sc,type='calibrated',datatype='vsvy'
	split_vec, 'rbsp'+sc+'_efw_vsvy', suffix='_V'+['1','2','3','4','5','6']
	
	;Antenna potentials
	tplot_options,'title','Single-ended potential'
	tplot,['rbsp'+sc+'_efw_vsvy_V1',$
		   'rbsp'+sc+'_efw_vsvy_V2',$
		   'rbsp'+sc+'_efw_vb2_available',$
		   'rbsp'+sc+'_efw_vb1_available']




;-------------------------------------------------------------------------------------
;CREATE DENSITY PROXY (V1 + V2)/2
;-------------------------------------------------------------------------------------



	get_data,'rbsp'+sc +'_efw_vsvy_V1',data=d1
	get_data,'rbsp'+sc +'_efw_vsvy_V2',data=d2
	
	datt = d1
	sum = (d1.y + d2.y)/2.
	
	datt.y = sum
	store_data,'density_proxy',data=datt
	options,'density_proxy','ytitle','(V1+V2)/2!C[volts]'
	
	
	rbsp_detrend,['density_proxy'],60.*5.
	
	tplot_options,'title','Density proxy'
	tplot,['rbsp'+sc+'_efw_vsvy_V1',$
		   'density_proxy',$
		   'density_proxy_detrend',$
		   'rbsp'+sc+'_efw_vb2_available',$
		   'rbsp'+sc+'_efw_vb1_available']


	



;-----------------------------------------------
;Create radius tplot variable
;-----------------------------------------------
	

	;Load spice for the GSE->MGSE transformation and for the radius variable
	rbsp_load_spice_kernels  ;attitude history


	rbsp_load_spice_state,probe=sc,coord='gse',/no_spice_load  
	
	get_data,'rbsp'+sc+'_state_pos_gse',data=pos_gse


	rad = sqrt(pos_gse.y[*,0]^2 + pos_gse.y[*,1]^2 + pos_gse.y[*,2]^2)/6370.
	store_data,'radius',data={x:pos_gse.x,y:rad}
	options,'radius','panel_size',0.6
	options,'radius','ytitle','Rad!C[RE]'





;-----------------------------------------------
;Load and despin the electric field data
;-----------------------------------------------


	;Load the Esvy data, despin it and transform it to MGSE
	rbsp_load_efw_esvy_mgse,probe=sc,/no_spice_load
	split_vec,'rbsp'+sc+'_efw_esvy_mgse'

	options,'rbsp'+sc+'_efw_esvy_mgse_y','colors',0	
	
	
	;Modified-GSE three components of Efield	
	;	x = spin axis
	tplot_options,'title','Esvy MGSE'
	tplot,['rbsp'+sc+'_efw_esvy_mgse_y',$
		   'rbsp'+sc+'_efw_esvy_mgse_z',$
		   'rbsp'+sc+'_efw_vb2_available',$
		   'rbsp'+sc+'_efw_vb1_available']
	
	
	
	






;--------------------------------------------------------------------
;The Esvy data are now in MGSE. Let's put the Bsvy data from EMFISIS into
;MGSE. Then we can do the vxB subtraction
;--------------------------------------------------------------------

	

	time2=time_double(date) ; first get unix time double for beginning of day

	;Grab first and last time of day
	time2 = [time2,time2+86399.]
	time3=time_string(time2, prec=6) ; turn it back into a string for ISO conversion
	strput,time3,'T',10 ; convert TPLOT time string 'yyyy-mm-dd/hh:mm:ss.msec' to ISO 'yyyy-mm-ddThh:mm:ss.msec'
	cspice_str2et,time3,et2 ; convert ISO time string to SPICE ET

	
	cspice_pxform,'RBSP'+strupcase(sc)+'_SCIENCE','GSE',et2[0],pxform1
	
	wsc1=dblarr(3)
	wsc1[2]=1d
	wsc_GSE=dblarr(3)
	
	;Direction of Z-antenna in GSE at start of day. Accurate to ~1 deg for entire day
	wsc_GSE = pxform1 ## wsc1




	;load EMFISIS 4sec GSE L3 data
	rbsp_load_emfisis,probe=sc,coord='gse',cadence='4sec',level='l3'  ;load this for the mag model subtract
	get_data,'rbsp'+sc+'_emfisis_l3_4sec_gse_Mag',data=dat
	store_data,'Mag_gse',data=dat



	;Transform EMFISIS survey data to MGSE
	rbsp_gse2mgse,'Mag_gse',reform(wsc_GSE),newname='Mag_mgse'


	;Transform sc velocity data to MGSE
	rbsp_gse2mgse,'rbsp'+sc+'_state_vel_gse',reform(wsc_GSE),newname='vel_mgse'



	;Remove the vxB component of the electric field
	rbsp_vxb_subtract,'vel_mgse','Mag_mgse','rbsp'+sc+'_efw_esvy_mgse'





	split_vec,'Esvy_mgse_vxb_removed'
	options,['Esvy_mgse_vxb_removed_x'],'ytitle','Ex!Cmgse!Cvxb!Cremoved!C[mV/m]'
	options,['Esvy_mgse_vxb_removed_y'],'ytitle','Ey!Cmgse!Cvxb!Cremoved!C[mV/m]'
	options,['Esvy_mgse_vxb_removed_z'],'ytitle','Ez!Cmgse!Cvxb!Cremoved!C[mV/m]'
	



	tplot_options,'title','Esvy vxB removed'
	tplot,['rbsp'+sc+'_efw_esvy_mgse_y',$
		   'Esvy_mgse_vxb_removed_y',$
		   'radius',$
		   'rbsp'+sc+'_efw_vb2_available','rbsp'+sc+'_efw_vb1_available']





	


;----------------------------------------
;Load spectral data
;----------------------------------------


	rbsp_load_efw_spec, probe=sc, type='calibrated'
		

	tplot,['rbsp'+sc +'_efw_64_spec0',$
		   'rbsp'+sc +'_efw_64_spec4','radius']






;-----------------------------------------
;Load filterbank data
;-----------------------------------------


	rbsp_load_efw_fbk, probe=sc, type='calibrated'
	
	rbsp_split_fbk,sc,/combine


	!p.charsize = 0.9
	tplot_options,'title','Filterbank'
	tplot,['rbsp'+sc +'_fbk1_13comb_12',$
		   'rbsp'+sc +'_fbk1_13comb_11',$
		   'rbsp'+sc +'_fbk1_13comb_10',$
		   'rbsp'+sc +'_fbk1_13comb_9',$
		   'rbsp'+sc +'_fbk1_13comb_8',$
		   'rbsp'+sc +'_fbk1_13comb_7',$
		   'rbsp'+sc +'_fbk1_13comb_6',$
		   'rbsp'+sc +'_fbk1_13comb_5',$
		   'rbsp'+sc +'_fbk1_13comb_4',$
		   'rbsp'+sc +'_fbk1_13comb_3',$
		   'rbsp'+sc +'_fbk1_13comb_2',$
		   'rbsp'+sc +'_fbk1_13comb_1',$
		   'rbsp'+sc +'_fbk1_13comb_0',$
		   'radius','rbsp'+sc +'_efw_64_spec0']



	
;-------------------------------------
;Load Xspec data
;-------------------------------------

	
		
	rbsp_load_efw_xspec, probe=sc,type='calibrated'
	
	!p.charsize = 1.2
	tplot_options,'title','Xspec'
	tplot,['rbsp'+sc+'_efw_xspec_64_xspec0_src1',$
		'rbsp'+sc+'_efw_xspec_64_xspec0_src2',$
		'rbsp'+sc+'_efw_xspec_64_xspec0_phase',$
		'rbsp'+sc+'_efw_xspec_64_xspec0_coh','radius',$
		'rbsp'+sc+'_efw_vb2_available','rbsp'+sc+'_efw_vb1_available']

	
	
	
	
	